@@ -2,11 +2,12 @@
 
 import json
 import re
+from copy import deepcopy
 from importlib.metadata import version
 from os.path import dirname, isfile, join
 
 from ..mixins import HasId, ParentType
-from ..models import Board, FlashRegion, Pcb, Role, RoleType, ShapeType, Side, Template
+from ..models import Board, FlashRegion, Pcb, RoleType, ShapeType, Side, Template
 from ..models.enums import RoleValue
 from ..shapes.base import Shape
 from ..shapes.circle import Circle
@@ -14,7 +15,7 @@ from ..shapes.group import ShapeGroup
 from ..shapes.label import Label
 from ..shapes.rect import Rect
 from ..shapes.text import Text
-from ..utils import load_json, var
+from ..utils import var
 from ..vector import V
 from .cache import CoreCache
 from .getters import CoreGetters
@@ -22,43 +23,39 @@ from .getters import CoreGetters
 
 class Core(CoreCache, CoreGetters):
     shape_ctors: dict[ShapeType, type]
-    is_libretuya: bool = False
+    is_libretiny: bool = False
 
-    _dir_base: str
+    dir_base: str
     _dirs_boards: list[str]
     _dirs_shapes: list[str]
     _dirs_templates: list[str]
-    _file_presets: str
-    _file_roles: str
-    _presets: dict[str, dict] = None
-    _roles: dict[RoleType, Role] = None
-    _flash: dict[str, str] = None
 
     def __init__(self) -> None:
-        self._dir_base = join(dirname(__file__), "..", "res")
+        self.dir_base = join(dirname(__file__), "..", "res")
         self._dirs_boards = [
-            join(dirname(__file__), "..", "..", "..", "..", "boards"),
-            join(self._dir_base, "boards"),
+            join(self.dir_base, "boards"),
             "boards",
         ]
         self._dirs_shapes = [
-            join(self._dir_base, "shapes"),
+            join(self.dir_base, "shapes"),
+            "boards/shapes",
+            "shapes",
         ]
         self._dirs_templates = [
-            join(self._dir_base, "templates"),
+            join(self.dir_base, "templates"),
+            "boards/templates",
+            "templates",
         ]
-        self._file_presets = join(self._dir_base, "presets.json")
-        self._file_roles = join(self._dir_base, "roles.json")
-        self._file_flash = join(self._dir_base, "flash.json")
+        self._file_presets = join(self.dir_base, "presets.json")
+        self._file_roles = join(self.dir_base, "roles.json")
+        self._file_flash = join(self.dir_base, "flash.json")
         self.shape_ctors = {
             ShapeType.RECT: Rect,
             ShapeType.CIRCLE: Circle,
             ShapeType.SUBSHAPE: ShapeGroup,
             ShapeType.TEXT: Text,
         }
-        self.is_libretuya = isfile(
-            join(dirname(__file__), "..", "..", "..", "..", "platform.json")
-        ) or isfile("families.json")
+        self.is_libretiny = isfile("families.json")
 
     @property
     def version(self) -> str | None:
@@ -101,11 +98,11 @@ class Core(CoreCache, CoreGetters):
         flash: dict = None,
     ):
         if presets:
-            self.presets |= presets
+            self.presets.update(presets)
         if roles:
-            self.roles |= roles
+            self.roles.update(roles)
         if flash:
-            self.flash |= flash
+            self.flash.update(flash)
 
     def build_shapes(self, name: str, parent: ParentType, pos: V = None) -> list[Shape]:
         """Load the specified shape JSON into a list of Shape objects.
@@ -151,17 +148,21 @@ class Core(CoreCache, CoreGetters):
             name (str): Board name.
         """
         manifest = self.load_board(name)
+        manifest = deepcopy(manifest)
         pcb = manifest.get("pcb", None)
         pinout = pcb.get("pinout", None) if pcb else None
         ic_pins = pcb.get("ic", None) if pcb else None
 
         if pinout:
-            for roles in pinout.values():
+            for pin, roles in pinout.items():
                 roles: dict[str, RoleValue]
                 # add IC pinout mapping from board manifest
                 ic_pin = str(roles.get("IC", None))
                 if ic_pins and ic_pin in ic_pins:
                     roles |= ic_pins[ic_pin]
+                # add physical pin number, if the name is numeric
+                if pin.isnumeric():
+                    roles["PHYSICAL"] = pin
 
                 for role_type, functions in dict(roles).items():
                     if role_type == "ARD":
@@ -225,9 +226,13 @@ class Core(CoreCache, CoreGetters):
             Side.BACK: [],
         }
         sources: list[HasId] = []
+        all_vars = dict(pcb.vars)
+        pcb.vars = all_vars
         for template_name in pcb.templates:
-            template = Template(**self.load_template(template_name))
+            template = Template(**deepcopy(self.load_template(template_name)))
             template.vars |= pcb.vars
+            all_vars |= template.vars
+            template.vars = all_vars
             pcb.pads |= template.pads
             pcb.test_pads |= template.test_pads
             sources.append(template)
