@@ -7,15 +7,16 @@ from svgwrite.container import Group
 from svgwrite.shapes import Rect
 from svgwrite.text import Text
 
+from ...utils import EvalFloat
 from ...vector import V
 from ..base import LabelShape
 
 
 class Block(LabelShape):
     text: str
-    padding: V = V(0.1, 0.2)
-    radius: float = 0.3
-    angle: float = 15
+    padding: V = V(0.05, 0.1)
+    radius: EvalFloat = 0.3
+    angle: EvalFloat = 15
 
     def draw(self, dwg: Drawing):
         g = Group()
@@ -42,7 +43,7 @@ class Block(LabelShape):
                 text="___",
                 insert=(text_pos.x, self.y1 - self.width / 16),
                 font_family="Consolas",
-                font_size=1.2,
+                font_size=self.label_size * 0.6,
                 text_anchor="middle",
                 dominant_baseline="middle",
             )
@@ -54,7 +55,7 @@ class Block(LabelShape):
             text=text,
             insert=text_pos.tuple,
             font_family="Consolas",
-            font_size=1.2,
+            font_size=self.label_size * 0.6,
             text_anchor="middle",
             dominant_baseline="central",
         )
